@@ -54,6 +54,7 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdTencentCloudImporter,
 		newCmdVultrImporter,
 		newCmdYandexImporter,
+		newCmdIonosCloudImporter,
 		// Infrastructure Software
 		newCmdKubernetesImporter,
 		newCmdOctopusDeployImporter,
@@ -77,6 +78,7 @@ func providerImporterSubcommands() []func(options ImportOptions) *cobra.Command
 		newCmdPagerDutyImporter,
 		newCmdOpsgenieImporter,
 		newCmdHoneycombioImporter,
+		newCmdOpalImporter,
 		// Community
 		newCmdKeycloakImporter,
 		newCmdLogzioImporter,
@@ -127,6 +129,7 @@ func providerGenerators() map[string]func() terraformutils.ProviderGenerator {
 		newNewRelicProvider,
 		newPagerDutyProvider,
 		newHoneycombioProvider,
+		newOpalProvider,
 		// Community
 		newKeycloakProvider,
 		newLogzioProvider,
