@@ -26,8 +26,8 @@ type NetworkSecurityGroupGenerator struct {
 }
 
 func (az *NetworkSecurityGroupGenerator) listResources() ([]network.SecurityGroup, error) {
-	subscriptionID, resourceGroup, authorizer := az.getClientArgs()
-	client := network.NewSecurityGroupsClient(subscriptionID)
+	subscriptionID, resourceGroup, authorizer, resourceManagerEndpoint := az.getClientArgs()
+	client := network.NewSecurityGroupsClientWithBaseURI(resourceManagerEndpoint, subscriptionID)
 	client.Authorizer = authorizer
 	var (
 		iterator network.SecurityGroupListResultIterator
@@ -55,12 +55,12 @@ func (az *NetworkSecurityGroupGenerator) listResources() ([]network.SecurityGrou
 }
 
 func (az *NetworkSecurityGroupGenerator) appendResource(resource *network.SecurityGroup) {
-	az.AppendSimpleResource(*resource.ID, *resource.Name, "azurerm_network_security_group")
+	az.AppendSimpleResourceWithDuplicateCheck(*resource.ID, *resource.Name, "azurerm_network_security_group")
 }
 
 func (az *NetworkSecurityGroupGenerator) appendRules(parent *network.SecurityGroup, resourceGroupID *ResourceID) error {
-	subscriptionID, _, authorizer := az.getClientArgs()
-	client := network.NewSecurityRulesClient(subscriptionID)
+	subscriptionID, _, authorizer, resourceManagerEndpoint := az.getClientArgs()
+	client := network.NewSecurityRulesClientWithBaseURI(resourceManagerEndpoint, subscriptionID)
 	client.Authorizer = authorizer
 	ctx := context.Background()
 	iterator, err := client.ListComplete(ctx, resourceGroupID.ResourceGroup, *parent.Name)
@@ -69,7 +69,7 @@ func (az *NetworkSecurityGroupGenerator) appendRules(parent *network.SecurityGro
 	}
 	for iterator.NotDone() {
 		item := iterator.Value()
-		az.AppendSimpleResource(*item.ID, *item.Name, "azurerm_network_security_rule")
+		az.AppendSimpleResourceWithDuplicateCheck(*item.ID, *item.Name, "azurerm_network_security_rule")
 		if err := iterator.NextWithContext(ctx); err != nil {
 			log.Println(err)
 			return err
